# coding: utf-8

"""
    Social Toolkit

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from ssdk_alpha_ti.models.brand_compass_response_schema import BrandCompassResponseSchema

class TestBrandCompassResponseSchema(unittest.TestCase):
    """BrandCompassResponseSchema unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> BrandCompassResponseSchema:
        """Test BrandCompassResponseSchema
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `BrandCompassResponseSchema`
        """
        model = BrandCompassResponseSchema()
        if include_optional:
            return BrandCompassResponseSchema(
                generations = [
                    ssdk_alpha_ti.models.generation_response_schema.GenerationResponseSchema(
                        brand_id = '', 
                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        generation_id = '', 
                        output_type = '', 
                        prompt = '', 
                        result = ssdk_alpha_ti.models.result.result(), 
                        status = 'NOT_STARTED', 
                        tenant_id = '', 
                        updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        use_source_context = True, 
                        worker_id = '', )
                    ],
                progress = ssdk_alpha_ti.models.brand_compass_progress_schema.BrandCompassProgressSchema(
                    completed_workers = 56, 
                    percent_complete = 1.337, 
                    total_workers = 56, ),
                status = ''
            )
        else:
            return BrandCompassResponseSchema(
                generations = [
                    ssdk_alpha_ti.models.generation_response_schema.GenerationResponseSchema(
                        brand_id = '', 
                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        generation_id = '', 
                        output_type = '', 
                        prompt = '', 
                        result = ssdk_alpha_ti.models.result.result(), 
                        status = 'NOT_STARTED', 
                        tenant_id = '', 
                        updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        use_source_context = True, 
                        worker_id = '', )
                    ],
                status = '',
        )
        """

    def testBrandCompassResponseSchema(self):
        """Test BrandCompassResponseSchema"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
