# coding: utf-8

"""
    Social Toolkit

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from ssdk_alpha_ti.models.source_response_schema import SourceResponseSchema

class TestSourceResponseSchema(unittest.TestCase):
    """SourceResponseSchema unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> SourceResponseSchema:
        """Test SourceResponseSchema
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `SourceResponseSchema`
        """
        model = SourceResponseSchema()
        if include_optional:
            return SourceResponseSchema(
                analysis_results = '',
                brand_id = '',
                location = '',
                name = '',
                source_id = '',
                source_type = '',
                status = '',
                tenant_id = ''
            )
        else:
            return SourceResponseSchema(
                analysis_results = '',
                brand_id = '',
                location = '',
                name = '',
                source_id = '',
                source_type = '',
                status = '',
                tenant_id = '',
        )
        """

    def testSourceResponseSchema(self):
        """Test SourceResponseSchema"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
