# coding: utf-8

"""
    Social Toolkit

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from ssdk_alpha_ti.api.source_api import SourceApi


class TestSourceApi(unittest.TestCase):
    """SourceApi unit test stubs"""

    def setUp(self) -> None:
        self.api = SourceApi()

    def tearDown(self) -> None:
        pass

    def test_tenant_tenant_id_brand_brand_id_source_get(self) -> None:
        """Test case for tenant_tenant_id_brand_brand_id_source_get

        List sources for a brand
        """
        pass

    def test_tenant_tenant_id_brand_brand_id_source_post(self) -> None:
        """Test case for tenant_tenant_id_brand_brand_id_source_post

        Create a new source for a brand
        """
        pass

    def test_tenant_tenant_id_brand_brand_id_source_source_id_delete(self) -> None:
        """Test case for tenant_tenant_id_brand_brand_id_source_source_id_delete

        Delete a source and its associated data
        """
        pass

    def test_tenant_tenant_id_brand_brand_id_source_source_id_get(self) -> None:
        """Test case for tenant_tenant_id_brand_brand_id_source_source_id_get

        Get source details
        """
        pass

    def test_tenant_tenant_id_brand_brand_id_source_source_id_reprocess_post(self) -> None:
        """Test case for tenant_tenant_id_brand_brand_id_source_source_id_reprocess_post

        Reprocess a source
        """
        pass


if __name__ == '__main__':
    unittest.main()
