# coding: utf-8

"""
    Social Toolkit

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from ssdk_alpha_ti.models.tenant_update_schema import TenantUpdateSchema

class TestTenantUpdateSchema(unittest.TestCase):
    """TenantUpdateSchema unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> TenantUpdateSchema:
        """Test TenantUpdateSchema
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `TenantUpdateSchema`
        """
        model = TenantUpdateSchema()
        if include_optional:
            return TenantUpdateSchema(
                brand_compass_worker_ids = [
                    ''
                    ],
                concurrency_limits = ssdk_alpha_ti.models.concurrency_limits.concurrency_limits(),
                description = '',
                name = '0',
                settings = ssdk_alpha_ti.models.tenant_settings_schema.TenantSettingsSchema(
                    anthropic_api_key = '', 
                    google_ai_api_key = '', 
                    openai_api_key = '', )
            )
        else:
            return TenantUpdateSchema(
        )
        """

    def testTenantUpdateSchema(self):
        """Test TenantUpdateSchema"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
